@@ -27,11 +27,10 @@ class _InnerClass:
         self.thread_ts = ""
 
 
-    def start_thread(self, text="", data={}, **kwargs):
+    def start_thread(self, text="start :tada:", data={}, **kwargs):
         time = str(datetime.now().isoformat(timespec='seconds'))
         info = "\n".join(f'{k}:\t{v}' for k, v in {**data, **kwargs}.items())
-        default_message = f"start :tada:"
-        text = (text or default_message) + f"\nstart time:{time}\n{info}"
+        text = text + f"\nstart time:\t{time}\n{info}"
 
         response = requests.post("https://slack.com/api/chat.postMessage",
             headers = self.headers,
